@@ -12,12 +12,15 @@ lazy_static! {
             let mut m: HashMap<String, f64> = vec![
                 ("1INCH/USDT", 1f64),
                 ("AAVE/USDT", 0.1f64),
+                ("ACH/USDT", 10f64),
                 ("ADA/USDT", 10f64),
                 ("AKRO/USDT", 100f64),
                 ("ALGO/USDT", 10f64),
                 ("ANKR/USDT", 10f64),
                 ("ATOM/USDT", 1f64),
                 ("AVAX/USDT", 1f64),
+                ("AXS/USDT", 0.1f64),
+                ("BADGER/USDT", 0.1f64),
                 ("BAGS/USDT", 0.01f64),
                 ("BAL/USDT", 0.1f64),
                 ("BAND/USDT", 1f64),
@@ -32,10 +35,13 @@ lazy_static! {
                 ("BTT/USDT", 1000f64),
                 ("CHR/USDT", 10f64),
                 ("CHZ/USDT", 10f64),
+                ("CLV/USDT", 1f64),
                 ("COMP/USDT", 0.01f64),
+                ("COTI/USDT", 10f64),
                 ("CRO/USDT", 10f64),
                 ("CRV/USDT", 1f64),
                 ("CSPR/USDT", 1f64),
+                ("CTSI/USDT", 10f64),
                 ("CVC/USDT", 10f64),
                 ("DASH/USDT", 0.1f64),
                 ("DOGE/USDT", 100f64),
@@ -45,6 +51,7 @@ lazy_static! {
                 ("ETC/USDT", 1f64),
                 ("ETH/USDT", 0.01f64),
                 ("FIL/USDT", 0.1f64),
+                ("FLOW/USDT", 0.1f64),
                 ("FORTH/USDT", 0.1f64),
                 ("FRONT/USDT", 1f64),
                 ("GRT/USDT", 10f64),
@@ -52,6 +59,7 @@ lazy_static! {
                 ("ICP/USDT", 0.01f64),
                 ("IOST/USDT", 100f64),
                 ("IOTA/USDT", 10f64),
+                ("IOTX/USDT", 10f64),
                 ("KAVA/USDT", 1f64),
                 ("KNC/USDT", 1f64),
                 ("KSM/USDT", 0.1f64),
@@ -66,9 +74,11 @@ lazy_static! {
                 ("MASS/USDT", 1f64),
                 ("MATIC/USDT", 100f64),
                 ("MDX/USDT", 1f64),
+                ("MIR/USDT", 1f64),
                 ("MKR/USDT", 0.001f64),
                 ("NEAR/USDT", 1f64),
                 ("NEO/USDT", 0.1f64),
+                ("NKN/USDT", 10f64),
                 ("O3/USDT", 1f64),
                 ("OGN/USDT", 1f64),
                 ("OMG/USDT", 1f64),
@@ -86,14 +96,18 @@ lazy_static! {
                 ("SKL/USDT", 10f64),
                 ("SNX/USDT", 1f64),
                 ("SOL/USDT", 1f64),
+                ("SRM/USDT", 1f64),
                 ("STORJ/USDT", 1f64),
                 ("SUSHI/USDT", 1f64),
+                ("SXP/USDT", 1f64),
                 ("THETA/USDT", 10f64),
+                ("TRIBE/USDT", 10f64),
                 ("TRX/USDT", 100f64),
                 ("UMA/USDT", 0.1f64),
                 ("UNI/USDT", 1f64),
                 ("VET/USDT", 100f64),
                 ("WAVES/USDT", 1f64),
+                ("WAXP/USDT", 10f64),
                 ("WOO/USDT", 10f64),
                 ("XCH/USDT", 0.001f64),
                 ("XEM/USDT", 10f64),
@@ -103,6 +117,7 @@ lazy_static! {
                 ("XTZ/USDT", 1f64),
                 ("YFI/USDT", 0.0001f64),
                 ("YFII/USDT", 0.001f64),
+                ("YGG/USDT", 1f64),
                 ("ZEC/USDT", 0.1f64),
                 ("ZEN/USDT", 0.1f64),
                 ("ZIL/USDT", 100f64),
